<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package ePortfolio
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function eportfolio_body_classes( $classes ) {
    global $post;
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}
    $global_layout = eportfolio_get_option( 'global_layout' );
	
    if ( $post && is_singular() ) {
        $post_options = get_post_meta( $post->ID, 'eportfolio-meta-select-layout', true );

        if (empty( $post_options ) ) {
            $global_layout = esc_attr( eportfolio_get_option('global_layout') );
        } else{
            $global_layout = esc_attr($post_options);
        }
    }

    if ( is_page_template( 'page-template/portfolio-template.php' ) ) {
      if ( (eportfolio_get_option('enable_portfolio_masonry_section') == 1) && (eportfolio_get_option('enable_portfolio_widget_sidebar') == 1) ) { 
        $classes[]= 'twp-page-template-portfolio-with-widget';
      } elseif ((eportfolio_get_option('enable_portfolio_masonry_section') == 1) && (eportfolio_get_option('enable_portfolio_widget_sidebar') != 1)) {
        $classes[]= 'twp-page-template-portfolio-only-gallery';
      }elseif ((eportfolio_get_option('enable_portfolio_masonry_section') != 1) && (eportfolio_get_option('enable_portfolio_widget_sidebar') == 1)) {
        $classes[]= 'twp-page-template-portfolio-only-widget';
      }
    }

    if ($global_layout == 'left-sidebar') {
        $classes[]= 'left-sidebar';
    }
    elseif ($global_layout == 'no-sidebar') {
        $classes[]= 'no-sidebar';
    }
    else{
        $classes[]= 'right-sidebar';
    }
	return $classes;
}
add_filter( 'body_class', 'eportfolio_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function eportfolio_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'eportfolio_pingback_header' );

if ( ! function_exists( 'eportfolio_display_posts_navigation' ) ) :
  /**
   * Display Pagination.
   *
   * @since 1.0.0
   */
  function eportfolio_display_posts_navigation() {
        $pagination_type = eportfolio_get_option( 'pagination_type', true );
        switch ( $pagination_type ) {
            case 'default':
                the_posts_navigation();
                break;
            case 'numeric':
                the_posts_pagination();
                break;
            default:
                break;
        }
    return;
  }
endif;
add_action( 'eportfolio_posts_navigation', 'eportfolio_display_posts_navigation' );


if ( ! function_exists( 'eportfolio_archive_title' ) ) :
    /**
     * Modifies post archive titles
     */
    function eportfolio_archive_title( $title) {
        if ( is_category() ) {
            $title = single_cat_title( '', false );
        } elseif ( is_tag() ) {
            $title = single_tag_title( '', false );
        } elseif ( is_author() ) {
            $title = '<span class="vcard">' . get_the_author() . '</span>';
        } elseif ( is_post_type_archive() ) {
            $title = post_type_archive_title( '', false );
        } elseif ( is_tax() ) {
            $title = single_term_title( '', false );
        }
        return $title;
    }
endif;
add_filter( 'get_the_archive_title', 'eportfolio_archive_title' );


if( ! function_exists( 'eportfolio_recommended_plugins' ) ) :

  /**
   * Recommended plugins
   *
   */
  function eportfolio_recommended_plugins(){
      $eportfolio_plugins = array(
        array(
            'name'     => __('Elementor Page Builder', 'eportfolio'),
            'slug'     => 'elementor',
            'required' => false,
        ),
        array(
          'name'     => __('Contact Form 7', 'eportfolio'),
          'slug'     => 'contact-form-7',
          'required' => false,
        ),
      );
      $eportfolio_plugins_config = array(
          'dismissable' => true,
      );
      
      tgmpa( $eportfolio_plugins, $eportfolio_plugins_config );
  }
endif;
add_action( 'tgmpa_register', 'eportfolio_recommended_plugins' );